@@ -1,5 +1,5 @@
 package XML::TMX;
-$XML::TMX::VERSION = '0.33';
+$XML::TMX::VERSION = '0.34';
 # ABSTRACT: Perl extensions for managing TMX files
 
 use 5.010;
@@ -26,7 +26,7 @@ XML::TMX - Perl extensions for managing TMX files
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -37,13 +37,23 @@ version 0.33
 XML::TMX is the top level module. At the moment it does not contain
 any useful code, so check sub-modules, please.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Alberto Simões <ambs@cpan.org> / José João Almeida <jj@di.uminho.pt>
+=over 4
+
+=item *
+
+Alberto Simões <ambs@cpan.org>
+
+=item *
+
+José João Almeida <jj@di.uminho.pt>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010-2017 by Projeto Natura.
+This software is copyright (c) 2010-2017 by Projeto Natura <natura@di.uminho.pt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
