@@ -1,5 +1,5 @@
 package XML::TMX::FromPO;
-$XML::TMX::FromPO::VERSION = '0.33';
+$XML::TMX::FromPO::VERSION = '0.34';
 # ABSTRACT: Generates a TMX file from a group of PO files
 
 use 5.010;
@@ -308,7 +308,7 @@ XML::TMX::FromPO - Generates a TMX file from a group of PO files
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -384,13 +384,23 @@ L<XML::TMX::Writer(3)>, L<gettext(1)>, L<recode(1)>, L<iconv(1)>
 
 Paulo Jorge Jesus Silva, E<lt>paulojjs@bragatel.ptE<gt>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Alberto Simões <ambs@cpan.org> / José João Almeida <jj@di.uminho.pt>
+=over 4
+
+=item *
+
+Alberto Simões <ambs@cpan.org>
+
+=item *
+
+José João Almeida <jj@di.uminho.pt>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010-2017 by Projeto Natura.
+This software is copyright (c) 2010-2017 by Projeto Natura <natura@di.uminho.pt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
