@@ -1,5 +1,5 @@
 package XML::TMX::Reader;
-$XML::TMX::Reader::VERSION = '0.33';
+$XML::TMX::Reader::VERSION = '0.34';
 # ABSTRACT: Perl extension for reading TMX files
 
 use 5.010;
@@ -330,7 +330,7 @@ XML::TMX::Reader - Perl extension for reading TMX files
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -479,13 +479,23 @@ L<XML::Writer(3)>, TMX Specification L<https://www.gala-global.org/oscarStandard
 
 Paulo Jorge Jesus Silva, E<lt>paulojjs@bragatel.ptE<gt>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Alberto Simões <ambs@cpan.org> / José João Almeida <jj@di.uminho.pt>
+=over 4
+
+=item *
+
+Alberto Simões <ambs@cpan.org>
+
+=item *
+
+José João Almeida <jj@di.uminho.pt>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010-2017 by Projeto Natura.
+This software is copyright (c) 2010-2017 by Projeto Natura <natura@di.uminho.pt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
