@@ -1,5 +1,5 @@
 package XML::TMX::Writer;
-$XML::TMX::Writer::VERSION = '0.33';
+$XML::TMX::Writer::VERSION = '0.34';
 # ABSTRACT: Perl extension for writing TMX files
 
 use 5.010;
@@ -253,7 +253,7 @@ XML::TMX::Writer - Perl extension for writing TMX files
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -524,13 +524,23 @@ TMX Specification L<https://www.gala-global.org/oscarStandards/tmx/tmx14b.html>
 
 Paulo Jorge Jesus Silva, E<lt>paulojjs@bragatel.ptE<gt>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Alberto Simões <ambs@cpan.org> / José João Almeida <jj@di.uminho.pt>
+=over 4
+
+=item *
+
+Alberto Simões <ambs@cpan.org>
+
+=item *
+
+José João Almeida <jj@di.uminho.pt>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010-2017 by Projeto Natura.
+This software is copyright (c) 2010-2017 by Projeto Natura <natura@di.uminho.pt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
